@@ -44,7 +44,7 @@ def get_mtime_and_size(path, tree):
                     raise
                 continue
             size += stats.st_size
-            files_mtimes[file_path] = stats.st_mtime
+            files_mtimes[os.fspath(file_path)] = stats.st_mtime
 
         # We track file changes and moves, which cannot be detected with simply
         # max(mtime(f) for f in non_ignored_files)
@@ -96,8 +96,7 @@ def move(src, dst, mode=None):
     tmp = f"{dst}.{uuid()}"
 
     if os.path.islink(src):
-        # readlink does not accept path-like obj for Windows in Python <3.8
-        shutil.copy(os.readlink(os.fspath(src)), tmp)
+        shutil.copy(src, tmp)
         os.unlink(src)
     else:
         shutil.move(src, tmp)
@@ -108,7 +107,7 @@ def move(src, dst, mode=None):
     shutil.move(tmp, dst)
 
 
-def _chmod(func, p, excinfo):
+def _chmod(func, p, excinfo):  # pylint: disable=unused-argument
     perm = os.lstat(p).st_mode
     perm |= stat.S_IWRITE
 
@@ -170,7 +169,6 @@ def makedirs(path, exist_ok=False, mode=None):
 
 def copyfile(src, dest, no_progress_bar=False, name=None):
     """Copy file with progress bar"""
-    from dvc.exceptions import DvcException
     from dvc.progress import Tqdm
 
     name = name if name else os.path.basename(dest)
